@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-cite-overlay" "1.1.1"
+(define-package "org-cite-overlay" "20251130.300"
   "Overlays for org-cite citations."
   '((emacs    "28.1")
     (citeproc "0.9.4"))
